pub trait DeltaMutator<S: Lattice>: Lattice {
// Required method
fn apply_to(&self, state: &S) -> S;
}Expand description
Delta-mutator trait for CRDTs
A delta-mutator produces a small delta that, when joined with the state, produces the same result as the full mutation.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.